@@ -34,7 +34,7 @@ import pprint
 import builtins
 import shutil
 
-__version__ = "26.0.3"
+__version__ = "26.0.4"
 
 from pathlib import Path
 
@@ -46,6 +46,7 @@ if Pythonista:
     import console
 else:
     import colorama
+
     colorama.just_fix_windows_console()
 
 try:
@@ -169,75 +170,75 @@ class _Peek:
 
         if value is None:
             return
-        if name == "output":
-            if callable(value):
-                return
-            if isinstance(value, (str, Path)):
-                return
-            try:
-                value.write("")
-                return
-            except Exception:
-                pass
-            raise AttributeError("output should be a callable, str, Path or open text file.")
+        match name:
+            case "output":
+                if callable(value):
+                    return
+                if isinstance(value, (str, Path)):
+                    return
+                try:
+                    value.write("")
+                    return
+                except Exception:
+                    pass
+                raise AttributeError("output should be a callable, str, Path or open text file.")
 
-        elif name == "serialize":
-            if callable(value):
-                return
-
-        elif name in ("color", "color_value"):
-            if isinstance(value, str) and value in _Peek._color_name_to_ANSI:
-                return
-            if isinstance(value, int) and value in _Peek.id_to_color:
-                return
-
-        elif name == "delta":
-            if isinstance(value, numbers.Number):
-                return
-
-        elif name == "line_length":
-            if (isinstance(value, numbers.Number) and value >= 0) or value == "terminal_width":
-                return
-
-        elif name == "indent":
-            if isinstance(value, numbers.Number) and value >= 0:
-                return
-
-        elif name == "level":
-            if isinstance(value, numbers.Number):
-                return
-
-        elif name == "max_lines":
-            if isinstance(value, numbers.Number) and value > 0:
-                return
-
-        elif name == "wrap_indent":
-            if isinstance(value, str):
-                return
-            if isinstance(value, numbers.Number):
-                if value > 0:
+            case "serialize":
+                if callable(value):
                     return
 
-        elif name == "format":
-            if isinstance(value, str):
-                return
-            try:
-                if all(isinstance(sub_format, str) for sub_format in value):
+            case "color" | "color_value":
+                if isinstance(value, str) and value in _Peek._color_name_to_ANSI:
+                    return
+                if isinstance(value, int) and value in _Peek.id_to_color:
                     return
-            except TypeError:
-                ...
 
-        elif name == "filter":
-            if value.strip() == "":
-                return
-            try:
-                eval(value, _Peek.name_and_alias_default)
-                return
-            except Exception:
-                ...
+            case "delta":
+                if isinstance(value, numbers.Number):
+                    return
 
-        else:
-            return
+            case "line_length":
+                if (isinstance(value, numbers.Number) and value >= 0) or value == "terminal_width":
+                    return
+
+            case "indent":
+                if isinstance(value, numbers.Number) and value >= 0:
+                    return
+
+            case "level":
+                if isinstance(value, numbers.Number):
+                    return
+
+            case "max_lines":
+                if isinstance(value, numbers.Number) and value > 0:
+                    return
+
+            case "wrap_indent":
+                if isinstance(value, str):
+                    return
+                if isinstance(value, numbers.Number):
+                    if value > 0:
+                        return
+
+            case "format":
+                if isinstance(value, str):
+                    return
+                try:
+                    if all(isinstance(sub_format, str) for sub_format in value):
+                        return
+                except TypeError:
+                    ...
+
+            case "filter":
+                if value.strip() == "":
+                    return
+                try:
+                    eval(value, _Peek.name_and_alias_default)
+                    return
+                except Exception:
+                    ...
+            case _:
+                return
 
         raise AttributeError(f"incorrect {name_org}: {repr(value)}{_Peek.in_read_toml_message}")
 
@@ -322,11 +323,13 @@ class _Peek:
     def return_args(args, return_none):
         if return_none:
             return None
-        if len(args) == 0:
-            return None
-        if len(args) == 1:
-            return args[0]
-        return args
+        match len(args):
+            case 0:
+                return None
+            case 1:
+                return args[0]
+            case _:
+                return args
 
     @staticmethod
     def perf_counter():
@@ -359,20 +362,21 @@ class _Peek:
             node = self
             while item not in node._attributes or node._attributes[item] is None:
                 node = node._parent
-            if item == "delta":
-                return _Peek.perf_counter() - node._attributes["delta1"] + node._attributes["delta"]
-            elif item == "delta1":
-                return node._attributes["delta"]
-            elif item == "prefix":
-                prefix = node._attributes[item]
-                return str(prefix() if callable(prefix) else prefix)
-            else:
-                return node._attributes[item]
+            match item:
+                case "delta":
+                    return _Peek.perf_counter() - node._attributes["delta1"] + node._attributes["delta"]
+                case "delta1":
+                    return node._attributes["delta"]
+                case "prefix":
+                    prefix = node._attributes[item]
+                    return str(prefix() if callable(prefix) else prefix)
+                case _:
+                    return node._attributes[item]
         else:
             return self.__getattribute__(item)
 
     def __setattr__(self, item, value):
-        if item in ("_parent", "_is_context_manager", "_line_number_with_filename_and_parent", "_save_traceback", "_enter_time", "_as_str", "_attributes"):
+        if item in ("_parent", "_line_number_with_filename_and_parent", "_save_traceback", "_enter_time", "_as_str", "_attributes"):
             return super().__setattr__(item, value)
         self._attributes.update(_Peek.spec_to_attributes(**{item: value}))
 
@@ -393,10 +397,12 @@ class _Peek:
         _Peek._fixed_perf_counter = val
 
     def do_show(self):
+        if not self.enabled:
+            return False
         if self.filter.strip() != "":
             if not eval(self.filter, {name: getattr(self, name) for name in list(_Peek.name_default) + list(_Peek.alias_default)}):
                 return False
-        return self.enabled
+        return True
 
     def print(self, *args, as_str=False, **kwargs):
         if "print" in kwargs and "print_like" in kwargs:
@@ -417,8 +423,19 @@ class _Peek:
             else:
                 pairs.append(Pair(left=left, right=right))
 
-        any_args = bool(args)
         this = self.fork(**kwargs)
+        if not this.do_show():
+            if this.decorator:
+                return lambda x: x
+            if this.context_manager:
+                return this
+            if as_str:
+                return ""
+            else:
+                return _Peek.return_args(args, this.return_none)
+
+        any_args = bool(args)
+
         if this.line_length in (0, "terminal_width"):
             this.line_length = shutil.get_terminal_size().columns
 
@@ -445,14 +462,6 @@ class _Peek:
         if this.decorator and this.context_manager:
             raise AttributeError("not allowed to specify both decorator and context_manager")
 
-        if not this.decorator and not this.do_show():
-            if as_str:
-                return ""
-            else:
-                return _Peek.return_args(args, this.return_none)
-
-        self._is_context_manager = False
-
         Pair = collections.namedtuple("Pair", "left right")
 
         call_frame = inspect.currentframe()
@@ -513,22 +522,19 @@ class _Peek:
                     args_kwargs = [repr(arg) for arg in args] + [f"{k}={repr(v)}" for k, v in kwargs.items()]
                     function_arguments = function.__name__ + "(" + (", ".join(args_kwargs)) + ")"
 
-                    if this.show_enter and this.do_show():
+                    if this.show_enter:
                         this.do_output(f"{context}called {function_arguments}{this.traceback()}")
                     result = function(*args, **kwargs)
                     duration = _Peek.perf_counter() - enter_time
 
                     context = this.context()
-                    if this.show_exit and this.do_show():
+                    if this.show_exit:
                         this.do_output(f"{context}returned {repr(result)} from {function_arguments} in {duration:.6f} seconds{this.traceback()}")
 
                     return result
 
                 return wrapper
 
-            if not this.do_show() or (not this.show_enter and not this.show_exit):
-                return lambda x: x
-
             if len(args) == 0:
                 return real_decorator
 
@@ -551,8 +557,6 @@ class _Peek:
                 raise TypeError("as_str may not be True when peek used as context manager")
             if any_args:
                 raise TypeError("non-keyword arguments are not allowed when peek used as context manager")
-
-            this._is_context_manager = True
             return this
 
         out = ""
@@ -687,8 +691,8 @@ class _Peek:
         self._attributes = save
 
     def __enter__(self):
-        if not hasattr(self, "_is_context_manager"):
-            raise ValueError("not allowed as context_manager")
+        if not self.do_show():
+            return self
         self._save_traceback = self.traceback()
         self._enter_time = _Peek.perf_counter()
         if self.show_enter:
@@ -697,18 +701,19 @@ class _Peek:
         return self
 
     def __exit__(self, *args):
-        if self.show_exit and self.do_show():
+        if not self.do_show():
+            return self
+        if self.show_exit:
             context = self.context()
             duration = _Peek.perf_counter() - self._enter_time
             self.do_output(f"{context}exit in {duration:.6f} seconds{self._save_traceback}")
-        self._is_context_manager = False
 
     def context(self, omit_line_number=False, omit_context_separator=False):
         if not omit_line_number and self.show_line_number and self._line_number_with_filename_and_parent != "":
             parts = [self._line_number_with_filename_and_parent]
         else:
             parts = []
-        if self.show_time and self.do_show():
+        if self.show_time:
             parts.append("@ " + str(datetime.datetime.now().strftime("%H:%M:%S.%f")))
 
         if self.show_delta:
@@ -749,38 +754,39 @@ class _Peek:
                 self.output(s_end, end="")
             else:
                 self.output(s_end)
-        elif self.output in ("stdout", "stderr"):
-            file = sys.stdout if self.output == "stdout" else sys.stderr
-            if Pythonista:
-                _Peek.print_pythonista_color(s_end, end="", file=file)
-            # elif Pyodide:  # not handled via use_color
-            #     _Peek.print_without_color(s, end=self.end, file=file)
-            else:
-                print(s_end, end="", file=file)
-        elif self.output == "logging.debug":
-            logging.debug(s)
-        elif self.output == "logging.info":
-            logging.info(s)
-        elif self.output == "logging.warning":
-            logging.warning(s)
-        elif self.output == "logging.error":
-            logging.error(s)
-        elif self.output == "logging.critical":
-            logging.critical(s)
-        elif self.output in ("", "null"):
-            pass
-        elif isinstance(self.output, str):
-            with open(self.output, "a+", encoding="utf-8") as f:
-                print(s_end, file=f, end="")
-        elif isinstance(self.output, Path):
-            with self.output.open("a+", encoding="utf-8") as f:
-                print(s_end, file=f, end="")
         else:
-            print(s_end, file=self.output, end="")
+            match self.output:
+                case "stdout" | "stderr":
+                    file = sys.stdout if self.output == "stdout" else sys.stderr
+                    if Pythonista:
+                        _Peek.print_pythonista_color(s_end, end="", file=file)
+                    else:
+                        print(s_end, end="", file=file)
+                case "logging.debug":
+                    logging.debug(s)
+                case "logging.info":
+                    logging.info(s)
+                case "logging.warning":
+                    logging.warning(s)
+                case "logging.error":
+                    logging.error(s)
+                case "logging.critical":
+                    logging.critical(s)
+                case "" | "null":
+                    pass
+                case _ if isinstance(self.output, str):
+                    with open(self.output, "a+", encoding="utf-8") as f:
+                        print(s_end, file=f, end="")
+                case _ if isinstance(self.output, Path):
+                    with self.output.open("a+", encoding="utf-8") as f:
+                        print(s_end, file=f, end="")
+                case _:
+                    print(s_end, file=self.output, end="")
 
     def copy_to_clipboard(self, value, confirm=True):
         if Pythonista:
             import clipboard
+
             clipboard.set(str(value))
         else:
             try:
