@@ -10,38 +10,32 @@ import shutil
 from pathlib import Path
 
 
-file_folder = Path(__file__).parent
-top_folder = (file_folder / ".." / "peek").resolve()
-sys.path.insert(0, str(top_folder))
-os.chdir(file_folder)
+import os, sys  # three lines to use the local package and chdir
+
+os.chdir(os.path.dirname(__file__))
+sys.path.insert(0, os.path.dirname(__file__) + "/../")
 
 import peek
 
 peek = peek.new(ignore_toml=True)
 
-dark_black=peek.ANSI.dark_black
-dark_red=peek.ANSI.dark_red
-dark_green=peek.ANSI.dark_green
-dark_yellow=peek.ANSI.dark_yellow
-dark_blue=peek.ANSI.dark_blue
-dark_magenta=peek.ANSI.dark_magenta
-dark_cyan=peek.ANSI.dark_cyan
-dark_white=peek.ANSI.dark_white
-black=peek.ANSI.black
-red=peek.ANSI.red
-green=peek.ANSI.green
-yellow=peek.ANSI.yellow
-blue=peek.ANSI.blue
-magenta=peek.ANSI.magenta
-cyan=peek.ANSI.cyan
-white=peek.ANSI.white
-reset=peek.ANSI.reset
-
-class g:
-    pass
-
-
-context_start = "#"
+dark_black = peek.ANSI.dark_black
+dark_red = peek.ANSI.dark_red
+dark_green = peek.ANSI.dark_green
+dark_yellow = peek.ANSI.dark_yellow
+dark_blue = peek.ANSI.dark_blue
+dark_magenta = peek.ANSI.dark_magenta
+dark_cyan = peek.ANSI.dark_cyan
+dark_white = peek.ANSI.dark_white
+black = peek.ANSI.black
+red = peek.ANSI.red
+green = peek.ANSI.green
+yellow = peek.ANSI.yellow
+blue = peek.ANSI.blue
+magenta = peek.ANSI.magenta
+cyan = peek.ANSI.cyan
+white = peek.ANSI.white
+reset = peek.ANSI.reset
 
 Pythonista = sys.platform == "ios"
 
@@ -67,7 +61,7 @@ def test_time(patch_datetime_now):
 def test_no_arguments(capsys):
     result = peek()
     out, err = capsys.readouterr()
-    assert out.startswith(context_start)
+    assert out.startswith("#")
     assert out.endswith(" in test_no_arguments()\n")
     assert result is None
 
@@ -107,7 +101,7 @@ def test_in_function(capsys):
 
     hello("world")
     out, err = capsys.readouterr()
-    assert out.startswith(context_start)
+    assert out.startswith("#")
     assert out.endswith(" in test_in_function.hello() ==> val='world'\n")
 
 
@@ -117,7 +111,7 @@ def test_in_function_no_parent(capsys):
 
     hello("world")
     out, err = capsys.readouterr()
-    assert out.startswith(context_start)
+    assert out.startswith("#")
     assert not out.endswith(" in test_in_function_no_parent.hello() ==> val='world'\n")
 
 
@@ -142,11 +136,12 @@ def test_time_delta():
 
 
 def test_dynamic_prefix(capsys):
-    g.i = 0
+    i = 0
 
     def prefix():
-        g.i += 1
-        return str(g.i) + ")"
+        nonlocal i
+        i += 1
+        return str(i) + ")"
 
     hello = "world"
     peek(hello, prefix=prefix)
@@ -209,10 +204,11 @@ def test_repr_and_str(capsys):
 
 
 def test_output(capsys, tmpdir):
-    g.result = ""
+    result = ""
 
     def my_output(s):
-        g.result += s
+        nonlocal result
+        result += s
 
     hello = "world"
     peek(hello, output=print)
@@ -271,7 +267,7 @@ def test_output(capsys, tmpdir):
     out, err = capsys.readouterr()
     assert out == ""
     assert out == ""
-    assert g.result == "hello='world'\n1\n"
+    assert result == "hello='world'\n1\n"
 
     def test_serialize(capsys):
         def serialize(s):
@@ -306,12 +302,12 @@ def test_as_str():
 
     with pytest.raises(TypeError):
 
-        @peek(as_str=True)
+        @peek(decorator=True, as_str=True)
         def add2(x):
             return x + 2
 
     with pytest.raises(TypeError):
-        with peek(as_str=True):
+        with peek(context_manager=True, as_str=True):
             pass
 
     with peek.preserve():
@@ -320,6 +316,7 @@ def test_as_str():
         assert s == "hello='world'\n"
 
 
+@pytest.mark.skipif(Pythonista, reason="Pythonista problem")
 def test_colored_end(capsys):
     hello = "world"
     s = peek(hello, color="red", end="|", as_str=True)
@@ -329,7 +326,6 @@ def test_colored_end(capsys):
     assert out == f"{red}hello='world'{reset}{red}|{reset}"
 
 
-@pytest.mark.skipif(Pythonista, reason="Pythonista problem")
 def test_print(capsys):
     peek.print(*range(4))
     peek.print(*range(4), sep="|")
@@ -510,6 +506,46 @@ def test_color(capsys):
         assert s == f"{blue}hello='world'{reset}\n"
 
 
+def test_numeric_colors():
+    with peek.preserve():
+        hello = "world"
+        s = peek(hello, as_str=True)
+        assert s == f"hello='world'\n"
+        s = peek(hello, as_str=True, color=3)
+        assert s == f"{red}hello='world'{reset}\n"
+
+        peek.color_value = 0
+        s = peek(hello, as_str=True)
+        assert s == f"hello='world'\n"
+        s = peek(hello, as_str=True, color=0)
+        assert s == f"hello='world'\n"
+        s = peek(hello, as_str=True, color=3)
+        assert s == f"{red}hello={reset}'world'{red}{reset}\n"
+
+        peek.color_value = 4
+        s = peek(hello, as_str=True)
+        assert s == f"hello={blue}'world'{reset}\n"
+        s = peek(hello, as_str=True, color=0)
+        assert s == f"hello={blue}'world'{reset}\n"
+        s = peek(hello, as_str=True, color=3)
+        assert s == f"{red}hello={blue}'world'{red}{reset}\n"
+        s = peek(hello, as_str=True, color=4)
+        assert s == f"{blue}hello='world'{reset}\n"
+
+
+def test_color_alias():
+    with peek.preserve():
+        peek.col = "red"
+        assert peek.color == peek.col == peek.c == "red"
+        peek.c = "green"
+        assert peek.color == peek.col == peek.c == "green"
+
+        peek.col_val = "red"
+        assert peek.color_value == peek.col_val == peek.cv == "red"
+        peek.cv = "green"
+        assert peek.color_value == peek.col_val == peek.cv == "green"
+
+
 def test_incorrect_filter():
     with pytest.raises(AttributeError):
         peek.filter = "color='blue'"
@@ -521,19 +557,19 @@ def test_incorrect_filter():
 def test_decorator(capsys):
     peek.fix_perf_counter(0)
 
-    @peek()
+    @peek(decorator=True)
     def div(x, y):
         return x / y
 
-    @peek(show_enter=False)
+    @peek(decorator=True, show_enter=False)
     def add(x, y):
         return x + y
 
-    @peek(show_exit=False)
+    @peek(decorator=True, show_exit=False)
     def sub(x, y):
         return x - y
 
-    @peek(show_enter=False, show_exit=False)
+    @peek(decorator=True, show_enter=False, show_exit=False)
     def pow(x, y):
         return x**y
 
@@ -557,7 +593,15 @@ called sub(10, 2)
 def test_decorator_edge_cases(capsys):
     peek.fix_perf_counter(0)
 
-    @peek()
+    @peek.as_decorator
+    def add2(x):
+        return x + 2
+
+    assert add2(2) == 4
+    out, err = capsys.readouterr()
+    assert out == "called add2(2)\nreturned 4 from add2(2) in 0.000000 seconds\n"
+
+    @peek(decorator=True)
     def mul(x, y, factor=1):
         return x * y * factor
 
@@ -576,6 +620,20 @@ called mul(5, 6, factor=10)
 returned 300 from mul(5, 6, factor=10) in 0.000000 seconds
 """
     )
+    a = 1
+
+    with pytest.raises(TypeError):
+
+        @peek(a, decorator=True)
+        def add2(x):
+            return x + 2
+
+    with pytest.raises(TypeError):
+
+        @peek.as_decorator(a)
+        def add2(x):
+            return x + 2
+
     peek.fix_perf_counter(None)
 
 
@@ -584,7 +642,7 @@ def test_decorator_with_methods(capsys):
         def __init__(self, value):
             self.value = value
 
-        @peek(show_exit=False)
+        @peek(decorator=True, show_exit=False)
         def __mul__(self, other):
             if isinstance(other, Number):
                 return self.value * other.value
@@ -616,10 +674,41 @@ called __mul__(Number(2), Number(3))
         )
 
 
-@pytest.mark.skipif(Pythonista, reason="Pythonista problem")
+def test_as_decorator(capsys):
+    @peek.as_decorator()
+    def add2(x):
+        return x + 2
+
+    add2(3)
+    out, err = capsys.readouterr()
+    assert out.startswith("called add2(3)\nreturned 5 from add2(3) in ")
+
+    @peek.as_d()
+    def add2(x):
+        return x + 2
+
+    add2(3)
+    out, err = capsys.readouterr()
+    assert out.startswith("called add2(3)\nreturned 5 from add2(3) in ")
+
+
+def test_as_context_manager(capsys):
+    with peek.as_context_manager():
+        print(1)
+
+    out, err = capsys.readouterr()
+    assert out.startswith("enter\n1\nexit in ")
+
+    with peek.as_cm():
+        print(1)
+
+    out, err = capsys.readouterr()
+    assert out.startswith("enter\n1\nexit in ")
+
+
 def test_context_manager(capsys):
     peek.fix_perf_counter(0)
-    with peek():
+    with peek(context_manager=True):
         peek(3)
     out, err = capsys.readouterr()
     assert (
@@ -879,29 +968,20 @@ def test_traceback(capsys):
         out, err = capsys.readouterr()
         assert out.count("traceback") == 2
 
-        @peek()
+        @peek(decorator=True)
         def p():
             pass
 
         p()
         out, err = capsys.readouterr()
         assert out.count("traceback") == 2
-        with peek():
+        with peek(context_manager=True):
             pass
         out, err = capsys.readouterr()
         assert out.count("traceback") == 2
 
 
 def test_check_output(capsys, tmpdir):
-    """special Pythonista code, as that does not reload x1 and x2"""
-    if "x1" in sys.modules:
-        del sys.modules["x1"]
-    if "x2" in sys.modules:
-        del sys.modules["x2"]
-    del sys.modules["peek"]
-    import peek
-
-    """ end of special Pythonista code """
     with peek.preserve():
         x1_file = tmpdir / "x1.py"
         with open(str(x1_file), "w") as f:
@@ -916,10 +996,10 @@ def check_output():
     peek(
     1
     )
-    with peek(prefix="==>"):
+    with peek(context_manager=True,prefix="==>"):
         peek()
 
-    with peek(
+    with peek(context_manager=True,
 
 
 
@@ -928,12 +1008,12 @@ def check_output():
         ):
         peek()
 
-    @peek()
+    @peek(decorator=True)
     def x(a, b=1):
         pass
     x(2)
 
-    @peek()
+    @peek(decorator=True)
 
 
 
@@ -955,13 +1035,13 @@ def check_output():
                 """\
 
 def test():
-    @peek()
+    @peek(decorator=True)
     def myself(x):
         peek(x)
         return x
 
     myself(6)
-    with peek():
+    with peek(context_manager=True):
         pass
 """,
                 file=f,
@@ -975,7 +1055,7 @@ def test():
     assert (
         out
         == """\
-#4[x2.py] in test() ==> called myself(6)
+#3[x2.py] in test() ==> called myself(6)
 #5[x2.py] in test.myself() ==> x=6
 #9[x2.py] in test() ==> enter
 #6[x1.py] in check_output() ==> 1
@@ -984,8 +1064,8 @@ def test():
 #11[x1.py] in check_output()
 ==>#13[x1.py] in check_output() ==> enter
 #20[x1.py] in check_output()
-#23[x1.py] in check_output() ==> called x(2)
-#32[x1.py] in check_output() ==> called x()
+#22[x1.py] in check_output() ==> called x(2)
+#27[x1.py] in check_output() ==> called x()
 """
     )
 
@@ -1212,6 +1292,7 @@ hello='world'
     )
 
 
+@pytest.mark.skipif(Pythonista, reason="Pythonista problem")
 def test_stop():
     with pytest.raises(SystemExit):
         peek.stop()
